.. _sardana-devel-controller-examples:

=========================
Controller examples
=========================


This code let you create a basic template of a controller.

(:download:`Source code <ControllerTemplate.py>`)

.. literalinclude:: ControllerTemplate.py
   :language: python
   :linenos:
   

